@@ -9,13 +9,11 @@ class Image:
     def __init__(self, image):
         if image: 
             self.image = image
-        if path:
-            self.image = self.seek(path)
 
         self.process()
 
     @classmethod
-    def fromFileName(cls, filename):
+    def fromPath(cls, filename):
         data = Image.seek(path)
         return cls(data)  
 
